@@ -84,22 +84,35 @@ EOF
     # the rest only allow ALLOWED_CONTENT.
     ANY_CONTENT = [ '!', '=' ].map(&:freeze)
 
-    attr_writer :otag, :ctag
+    attr_reader :otag, :ctag
 
     # Accepts an options hash which does nothing but may be used in
     # the future.
     def initialize(options = {})
-      @options = {}
+      @options = options
+      @option_inline_partials_at_compile_time = options[:inline_partials_at_compile_time]
+      if @option_inline_partials_at_compile_time
+        @partial_resolver = options[:partial_resolver]
+        raise ArgumentError.new "Missing or invalid partial_resolver" unless @partial_resolver.respond_to? :call
+      end
+
+      # Initialize default tags
+      self.otag ||= '{{'
+      self.ctag ||= '}}'
     end
 
     # The opening tag delimiter. This may be changed at runtime.
-    def otag
-      @otag ||= '{{'
+    def otag=(value)
+      regex = regexp value
+      @otag_regex     = /([ \t]*)?#{regex}/
+      @otag_not_regex = /(^[ \t]*)?#{regex}/
+      @otag = value
     end
 
     # The closing tag delimiter. This too may be changed at runtime.
-    def ctag
-      @ctag ||= '}}'
+    def ctag=(value)
+      @ctag_regex = regexp value
+      @ctag = value
     end
 
     # Given a string template, returns an array of tokens.
@@ -134,9 +147,9 @@ EOF
     private
 
 
-    def content_tags type, current_ctag
+    def content_tags type, current_ctag_regex
       if ANY_CONTENT.include?(type)
-        r = /\s*#{regexp(type)}?#{regexp(current_ctag)}/
+        r = /\s*#{regexp(type)}?#{current_ctag_regex}/
         scan_until_exclusive(r)
       else
         @scanner.scan(ALLOWED_CONTENT)
@@ -147,8 +160,8 @@ EOF
       send("scan_tag_#{type}", content, fetch, padding, pre_match_position)
     end
 
-    def find_closing_tag scanner, current_ctag
-      error "Unclosed tag" unless scanner.scan(regexp(current_ctag))
+    def find_closing_tag scanner, current_ctag_regex
+      error "Unclosed tag" unless scanner.scan(current_ctag_regex)
     end
 
     # Find {{mustaches}} and add them to the @result array.
@@ -158,7 +171,7 @@ EOF
       pre_match_position = @scanner.pos
       last_index = @result.length
 
-      return unless @scanner.scan(/([ \t]*)?#{Regexp.escape(otag)}/)
+      return unless @scanner.scan @otag_regex
       padding = @scanner[1] || ''
 
       # Don't touch the preceding whitespace unless we're matching the start
@@ -171,13 +184,13 @@ EOF
 
       # Since {{= rewrites ctag, we store the ctag which should be used
       # when parsing this specific tag.
-      current_ctag = self.ctag
+      current_ctag_regex = @ctag_regex
       type = @scanner.scan(self.class.valid_types)
       @scanner.skip(/\s*/)
 
       # ANY_CONTENT tags allow any character inside of them, while
       # other tags (such as variables) are more strict.
-      content = content_tags(type, current_ctag)
+      content = content_tags(type, current_ctag_regex)
 
       # We found {{ but we can't figure out what's going on inside.
       error "Illegal content in tag" if content.empty?
@@ -196,7 +209,7 @@ EOF
       @scanner.skip(/\s+/)
       @scanner.skip(regexp(type)) if type
 
-      find_closing_tag(@scanner, current_ctag)
+      find_closing_tag(@scanner, current_ctag_regex)
 
       # If this tag was the only non-whitespace content on this line, strip
       # the remaining whitespace.  If not, but we've been hanging on to padding
@@ -218,7 +231,7 @@ EOF
 
     # Try to find static text, e.g. raw HTML with no {{mustaches}}.
     def scan_text
-      text = scan_until_exclusive(/(^[ \t]*)?#{Regexp.escape(otag)}/)
+      text = scan_until_exclusive @otag_not_regex
 
       if text.nil?
         # Couldn't find any otag, which means the rest is just static text.
@@ -263,7 +276,7 @@ EOF
     # Used to quickly convert a string into a regular expression
     # usable by the string scanner.
     def regexp(thing)
-      /#{Regexp.escape(thing)}/
+      Regexp.new Regexp.escape(thing) if thing
     end
 
     # Raises a SyntaxError. The message should be the name of the
@@ -334,7 +347,13 @@ EOF
 
 
     def scan_tag_open_partial content, fetch, padding, pre_match_position
-      @result << [:mustache, :partial, content, offset, padding]
+      @result << if @option_inline_partials_at_compile_time
+        partial = @partial_resolver.call content
+        partial.gsub!(/^/, padding) unless padding.empty?
+        self.class.new(@options).compile partial
+      else
+        [:mustache, :partial, content, offset, padding]
+      end
     end
     alias_method :'scan_tag_<', :scan_tag_open_partial
     alias_method :'scan_tag_>', :scan_tag_open_partial
